declare interface INotifyClientCredentials {
    /** The IoT hub endpoint to subscribe. */
    host: string;
    /** The access key. */
    accessKeyId: string;
    /** The secret key. */
    secretKey: string;
    /** The session token. */
    sessionToken: string;
    /** The time when temporary session credentials expire. Client have to ask for new credentials after expiration. */
    expiresAt: Date;
}

declare class NotifyClient {
    public credentials?: INotifyClientCredentials;

    constructor(credentials: INotifyClientCredentials);

    public on(event: "connect" | "close" | "reconnect" | "offline", listener: () => void): this;
    public on(event: "error", listener: (error: Error | string) => void): this;
    public on(event: "message", listener: (topic: string, payload: string) => void): this;

    public publish(topic: string, payload: string): void;
    public subscribe(topic: string | string[]): void;
    public unsubscribe(topic: string | string[]): void;
    public updateCredentials(credentials: INotifyClientCredentials): void;
    public end(): void;
}
